jacinle.comm.distrib.name\_server
=================================

.. automodule:: jacinle.comm.distrib.name_server

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      NameServer
      NameServerControllerStorage
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      run_name_server
   
   

   
   
   








.. rubric:: Class NameServer
.. autoclass:: NameServer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class NameServerControllerStorage
.. autoclass:: NameServerControllerStorage
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: run_name_server


